import { AxiosRequestConfig } from "axios";
import { JWT } from "jwt.js";
export interface IKuboOption {
}
export interface IKuboArg {
    path: string;
    arg: string;
    long: boolean;
    U: boolean;
    format: string;
    hash: boolean;
    size: boolean;
    "with-local": boolean;
    parents: boolean;
    recursive: boolean;
    force: boolean;
    "cid-version": string;
    offset: number;
    count: number;
    progress: boolean;
}
export type TFilesLsArgs = Partial<Pick<IKuboArg, "long" | "path" | "U">>;
export type TFilesLsEntry = {
    Hash: string;
    Name: string;
    Size: number;
    Type: number;
};
export type TFilesStatArgs = Partial<Pick<IKuboArg, "arg" | "format" | "hash" | "size" | "with-local">>;
export type TFilesStatEntry = {
    Blocks: number;
    CumulativeSize: number;
    Hash: string;
    Local: boolean;
    Size: number;
    SizeLocal: number;
    Type: string;
    WithLocality: boolean;
};
export type TFilesAdd = {
    Name: string;
    Hash: string;
    Size: number;
};
export type TFilesRmArgs = Partial<Pick<IKuboArg, "arg" | "recursive" | "force">>;
export type TFilesMkdirArgs = Partial<Pick<IKuboArg, "arg" | "parents" | "cid-version" | "hash">>;
export type TFilesReadArgs = Partial<Pick<IKuboArg, "arg" | "offset" | "count">>;
export type TPinAddArgs = Partial<Pick<IKuboArg, "arg" | "recursive" | "progress">>;
export type TPinAdd = {
    Pins: string[];
    Progress: number;
};
export type TNamePublish = {
    Name: string;
    Value: string;
};
export type TNameResolve = {
    Path: string;
};
export type TNameKeyList = {
    Keys: {
        Id: string;
        Name: string;
    }[];
};
export declare const REQUIRED_AUTHENTICATION: string[];
export type TKuboAuthentication = {
    username: string;
    secretKey: string;
};
export type TKuboConfig = {
    protocol: "http" | "https";
    host: string;
    port: number;
    apiPath: string;
    authentication?: TKuboAuthentication;
};
export declare class RequestBuilder {
    options: Partial<IKuboOption>;
    command: string;
    args: Partial<IKuboArg>;
    constructor(comand: string, defaultOpt?: Partial<IKuboOption>, defautArgs?: Partial<IKuboArg>);
    option<K extends keyof Partial<IKuboOption>, V extends Partial<IKuboOption>[K]>(key: K, value: V): RequestBuilder;
    arg<K extends keyof Partial<IKuboArg>, V extends Partial<IKuboArg>[K]>(key: K, value: V): RequestBuilder;
    static new(comand: string, defaultOpt?: Partial<IKuboOption>, defautArgs?: Partial<IKuboOption>): RequestBuilder;
}
export declare class KuboClient {
    config: TKuboConfig;
    jwt?: JWT;
    constructor(config?: Partial<TKuboConfig>);
    private getUrl;
    exist(path: string): Promise<boolean>;
    existFile(path: string): Promise<boolean>;
    existDir(path: string): Promise<boolean>;
    filesLs(args?: TFilesLsArgs): Promise<TFilesLsEntry[]>;
    filesStat(args?: TFilesStatArgs): Promise<TFilesStatEntry>;
    filesRm(args: TFilesRmArgs): Promise<void>;
    filesAdd(filename: string, filecontent: Uint8Array): Promise<TFilesAdd>;
    filesCp(src: string, dst: string): Promise<TFilesAdd>;
    filesMkdir(args: TFilesMkdirArgs): Promise<unknown>;
    filesWrite(path: string, content: Uint8Array): Promise<TFilesAdd>;
    filesRead(args?: TFilesReadArgs): Promise<ArrayBuffer>;
    pinAdd(args: TPinAddArgs): Promise<TPinAdd>;
    namePublish(arg?: string): Promise<TNamePublish>;
    nameResolve(arg: string): Promise<TNameResolve>;
    keyList(): Promise<{
        Id: string;
        Name: string;
    }[]>;
    execute<T>(requestBuilder: RequestBuilder, configHeaders?: any, requestOptions?: AxiosRequestConfig): Promise<T>;
}
//# sourceMappingURL=index.d.ts.map